@@ -9,17 +9,16 @@ os_info = {
         "archive_manager": {
             "file_name": "libglasswall.archive.manager.so",
             "dependencies": [],
+            "relies_on": ["editor"],
         },
         "editor": {
             "file_name": "libglasswall_core2.so",
             "dependencies": [],
         },
-        "cli": {
-            "file_name": [
-                "gwcli",
-                "GWQtCLI"
-            ],
+        "editor_cli": {
+            "file_name": "gwcli",
             "dependencies": [],
+            "relies_on": ["editor"],
         },
         "rebuild": {
             "file_name": "libglasswall.classic.so",
@@ -35,10 +34,13 @@ os_info = {
                 "libQt5Multimedia.so.5",
                 "libQt5XmlPatterns.so.5"
             ],
+            "relies_on": ["editor"],
         },
         "word_search": {
             "file_name": "libglasswall.word.search.so",
-            "dependencies": [],  # loading dependencies through ctypes doesn't help for word search, use LD_LIBRARY_PATH
+            # loading dependencies through ctypes doesn't help for word search, use LD_LIBRARY_PATH
+            "dependencies": [],
+            "relies_on": ["editor"],
         },
     },
 
@@ -46,6 +48,7 @@ os_info = {
         "archive_manager": {
             "file_name": "glasswall.archive.manager.dll",
             "dependencies": [],
+            "relies_on": ["editor"],
         },
         "editor": {
             "file_name": "glasswall_core2.dll",
@@ -54,12 +57,10 @@ os_info = {
                 "Qt5Xml.dll"
             ],
         },
-        "cli": {
-            "file_name": [
-                "gwcli.exe",
-                "GWQtCLI.exe"
-            ],
+        "editor_cli": {
+            "file_name": "gwcli.exe",
             "dependencies": [],
+            "relies_on": ["editor"],
         },
         "rebuild": {
             "file_name": "glasswall.classic.dll",
@@ -74,10 +75,12 @@ os_info = {
                 "Qt5XmlPatterns.dll",
                 "Qt5Network.dll"
             ],
+            "relies_on": ["editor"],
         },
         "word_search": {
             "file_name": "glasswall.word.search.dll",
             "dependencies": [],
+            "relies_on": ["editor"],
         },
     },
 }
